@@ -10,3 +10,6 @@ from pybsc.split import nsplit
 
 from pybsc.iter_utils import pairwise
 from pybsc.iter_utils import triplewise
+
+from pybsc.json_utils import load_json
+from pybsc.json_utils import save_json
